@@ -173,8 +173,7 @@ def django_instance_field_to_redis_value(
         redis_root,
         create_redis_model_from_django_model
 ):
-    print(django_instance.__class__)
-    print(django_instance.__class__._meta.get_all_field_names())
+    print(django_instance.__class__._meta.get_fields())
     django_field_value = getattr(django_instance, django_field.name)
     redis_value = django_field_value
     if django_field.__class__ == django_fields.ForeignKey:
@@ -203,14 +202,18 @@ def django_instance_to_redis_params(
         create_redis_model_from_django_model
 ):
     redis_params = {}
+    exclude_fields = [
+        'ManyToOneRel',
+    ]
     for i, django_field in enumerate(django_instance.__class__._meta.get_fields()):
-        redis_param = django_instance_field_to_redis_value(
-            django_instance,
-            django_field,
-            redis_root,
-            create_redis_model_from_django_model
-        )
-        redis_params[django_field.name] = redis_param
+        if django_field.__class__.__name__ not in exclude_fields:
+            redis_param = django_instance_field_to_redis_value(
+                django_instance,
+                django_field,
+                redis_root,
+                create_redis_model_from_django_model
+            )
+            redis_params[django_field.name] = redis_param
     return redis_params
 
 
