@@ -453,6 +453,10 @@ class RedisRoot:
                             allowed_redis_params[django_field_param_name] = value
                     return allowed_redis_params
 
+                exclude_fields = [
+                    'ManyToOneRel',
+                ]
+
                 field_mapping = {
                     django_models.BooleanField: RedisBool,
                     django_models.DecimalField: RedisDecimal,
@@ -476,26 +480,32 @@ class RedisRoot:
                     django_models.ManyToManyField: RedisManyToMany
                 }
 
-                redis_field = RedisString
-                if django_field.__class__ in field_mapping.keys():
+
+                if django_field.__class__.__name__ in exclude_fields:
+                    redis_field = None
+                elif django_field.__class__ in field_mapping.keys():
                     redis_field = field_mapping[django_field.__class__]
+                else:
+                    redis_field = RedisString
 
                 print(django_field.__class__.__name__)
-                redis_field = type(
-                    django_field.__class__.__name__,
-                    (redis_field,),
-                    get_allowed_params(django_field)
-                )
+                if redis_field:
+                    redis_field = type(
+                        django_field.__class__.__name__,
+                        (redis_field,),
+                        get_allowed_params(django_field)
+                    )
                 return redis_field
 
             def create_redis_model_from_django_model(django_model, redis_root):
                 redis_fields = {}
                 for django_field in django_model._meta.get_fields():
                     redis_field = django_field_to_redis_field(django_model, django_field)
-                    django_field_name = django_field.name
-                    if django_field_name in ['id', 'pk']:
-                        django_field_name = 'django_id'
-                    redis_fields[django_field_name] = redis_field
+                    if redis_field:
+                        django_field_name = django_field.name
+                        if django_field_name in ['id', 'pk']:
+                            django_field_name = 'django_id'
+                        redis_fields[django_field_name] = redis_field
 
                 new_redis_model = type(django_model.__name__, (RedisModel,), redis_fields)
 
